# FileSpec

FileSpec is a File-based testing library for JavaScript/TypeScript.

![](https://raw.githubusercontent.com/jameskolce/FileSpec/master/screenshot.png)

## Installation

```
npm install -D filespec
```

## Workflow

To use FileSpec you can create testing files ending with any of the following patterns: `*.spec.ts`, `*.spec.js`, `*.test.ts`, `*.test.js`. They can be located anywhere in your project but it's recommented to put them next to the source files being tested.

For example, suppose you have a `src` directory with a `routes.ts` file, you can create a `routes.spec.ts` file and execute the tests with the `filespec src` command.

## Writing Tests

Each test file must export an array containing all the tests, even if you only have one. The general structure is as follows:

```js
// feature.spec.ts file
export default [
  "Feature Description",

  Test => {
    return Test('Test Description', assertion)
  }
]
```

You can have one description for all the test as the first element of the array, this is useful to distinguish between several files since it's the first thing shown in the test results.

The rest of the array is any number of functions that take another function as argument and return the application of that function with a test description and the assertion, which must have a boolean value; if this value is true then the test is marked as successful, otherwise it's marked as failed.

You can name the test functions as you like, but keeping it as `Test` can be a good convention to follow.

The following is a another example of a test file:

```js
// routes.spec.ts file
export default [
  "Server Routes",

  Test => {
    const route = '/'
    const actual = getRouteMessage(route)

    return Test('Single Test Description',
      actual === 'Hello World!'
    )
  },

  Test => {
    return Test('A single test', true)
  },

  myOtherTest => {
    return MyOtherTest('A custom-named test', true)
  }
]
```

Executing the `filespec <projectDir>` command will run those tests and return the results.

![](https://raw.githubusercontent.com/jameskolce/FileSpec/master/screenshot2.png)

## Usage with TypeScript

You can run TypeScript files using the `ts-node` package. First install it as a development dependency:

```
npm install -D ts-node
```

And then run the FileSpec command with it:

```
ts-node node_modules/filespec/dist/bin <projectDir>
```

This is necessary because embedding the TypeScript compiler in FileSpec and making it work is not trivial when the tests have dependencies. If you know a simple solution for this where we don't need to manually resolve the dependencies please open an issue and let me know.

## Licence

MIT License - James Kolce
