"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
exports.default = (testsDir) => {
    // Walk the source directory looking for the tests
    const specFiles = walkDir(testsDir, /\.(spec|test)\.(ts|js)$/);
    // Get how many tests succeded and how many failed
    return Promise.all(specFiles.map(specFile => {
        // Require the test file
        const source = require(specFile);
        // If it's a TypeScript file use the `default` object
        const tests = /.ts$/.test(specFile) ? source.default : source;
        // Check if we received an array of tests
        if (!Array.isArray(tests))
            throw new Error('Each test file must export an array of tests');
        // Get the results and keep the tests description untouched
        const results = tests.map(test => typeof test === 'string' ? test : test(log));
        // Return a promise for all the results
        return Promise.all(results);
    }));
};
// Walk over the source directory looking for test files
// and return an array of files found
function walkDir(dir, pattern, filelist = []) {
    fs.readdirSync(dir).forEach(file => {
        // Get the full path
        const filePath = path.join(dir, file);
        filelist = fs.statSync(filePath).isDirectory() // Check if we are in a directory then
            ? walkDir(filePath, pattern, filelist) // Continue the recursion
            : filelist.concat(pattern.test(file) ? filePath : ''); // Otherwise check if it's a test file
    });
    // Return the list of found files
    return filelist.filter(x => x);
}
// Log the tests with colors and indicators
function log(message, assertion) {
    return { message, assertion };
}
