#!/usr/bin/env node

import tests from "../";
import * as path from 'path'
import chalk from 'chalk'

// Get the results
tests(path.join(process.cwd(), process.argv[2])).then((preResults) => {

  const results = preResults.map((testGroup) => {
    typeof testGroup[0] === 'string' && console.log(chalk.blue.bold(`\n${testGroup.shift()}`))

    const results = testGroup.map((test): number => {
      const result = test.assertion
        ? chalk.green(`    ✔ ${test.message} `)
        : chalk.red(`    ✖ ${test.message} `)

      console.log(result)

      return test.assertion ? 1 : 0
    })

    const totalTests = results.length
    const howManySucceded = results.reduce((x, sum) => x + sum)
    const howManyFailed = totalTests - howManySucceded

    // Return the stats
    return [howManySucceded, howManyFailed]
  }).reduce((x, xs) => [x[0] + xs[0], x[1] + xs[1]])

  console.log(chalk.blue.bold(`\nResults for all ${results[0] + results[1]} tests: `))
  console.log(
    chalk.green(`    ✔ Succeded: ${results[0]} `) +
    chalk.red(`    ✖ Failed: ${results[1]} \n`)
  )

  // Exit with code 0 if there are no errors
  process.exitCode = results[1] === 0 ? 0 : 1
})
